from django.db import models
from django.contrib.auth.models import User
from django.core.exceptions import ObjectDoesNotExist
from django.utils import timezone
from django.utils.translation import ugettext as _
from ohm2_handlers_light.models import BaseModel
from ohm2_handlers_light import utils as h_utils
from . import managers
from . import settings



class PasswordReset(BaseModel):
	user = models.ForeignKey(User, on_delete = models.CASCADE)
	last_sent_date = models.DateTimeField(null = True, blank = True, default = None)
	activation_date = models.DateTimeField(null = True, blank = True, default = None)
	ip_address = models.GenericIPAddressField(null = True, blank = True, default = "")
	code = models.CharField(max_length = settings.PASSWORDRESET_CODE_MAX_LENGTH, unique = True)


	def send_again(self):
		if self.last_sent_date and not h_utils.is_older_than_now(self.last_sent_date, seconds = settings.MINIMUM_PASSWORD_RESET_DELAY):
			return False
		return True

	def __str__(self):
		return self.user.username


from django.apps import apps
from ohm2_accounts_light import utils as ohm2_accounts_light


def user_avatar(request, user, previous_outputs, *args, **kwargs):
	output = {}
	
	#avatar = apps.get_model()
	
	return (user, output)



from django import VERSION as DJANGO_VERSION

if DJANGO_VERSION >= (2, 0):
	from django.urls import include, re_path as url
else:
	from django.conf.urls import include, url

from . import settings
from . import views

app_name = "ohm2_accounts_light_api_v1"

urlpatterns = [
	url(r'^signup/$', views.signup, name = 'signup'),
	url(r'^login/$', views.login, name = 'login'),
	url(r'^logout/$', views.logout, name = 'logout'),
	url(r'^signup-and-get-token/$', views.signup_and_get_token, name = 'signup_and_get_token'),
	url(r'^login-and-get-token/$', views.login_and_get_token, name = 'login_and_get_token'),
]

if settings.INCLUDE_PATCHED_URLS:
	urlpatterns += [
		url(r'^signup-and-get-token/patched/$', views.signup_and_get_token_patched, name = 'signup_and_get_token_patched'),
		url(r'^login-and-get-token/patched/$', views.login_and_get_token_patched, name = 'login_and_get_token_patched'),
	]

urlpatterns += [
	url(r'^send-password-reset-link/$', views.send_password_reset_link, name = 'send_password_reset_link'),
	url(r'^set-password-reset/$', views.set_password_reset, name = 'set_password_reset'),
	url(r'^set-password-reset-and-get-token/$', views.set_password_reset_and_get_token, name = 'set_password_reset_and_get_token'),
	url(r'^update-user-information/$', views.update_user_information, name = 'update_user_information'),
]


if settings.ENABLE_SOCIAL_LOGIN:
	urlpatterns += [
		url(r'^', include('social.apps.django_app.urls', namespace = 'social')),
	]


if settings.FACEBOOK_LOGIN:
	urlpatterns += [
		url(r'^facebook/login-and-get-token/$', views.facebook_login_and_get_token, name = 'facebook_login_and_get_token'),
	]
	if settings.INCLUDE_PATCHED_URLS:
		urlpatterns += [
			url(r'^facebook/login-and-get-token/patched/$', views.facebook_login_and_get_token_patched, name = 'facebook_login_and_get_token_patched'),
		]

if settings.GOOGLE_PLUS_LOGIN:
	urlpatterns += [
		url(r'^google-plus/login-and-get-token/$', views.google_plus_login_and_get_token, name = 'google_plus_login_and_get_token'),
	]
	if settings.INCLUDE_PATCHED_URLS:
		urlpatterns += [
			url(r'^google-plus/login-and-get-token/patched/$', views.google_plus_login_and_get_token_patched, name = 'google_plus_login_and_get_token_patched'),
		]


from django.shortcuts import redirect
from ohm2_handlers_light.decorators import ohm2_handlers_light_safe_request
from functools import wraps

def ohm2_accounts_light_safe_request(function):
	return ohm2_handlers_light_safe_request(function, "accounts")

def ohm2_accounts_light_redirect_if_authenticated(redirect_url = "/"):

	def decorator(view_function):
		@wraps(view_function)
		def wrapped_view(request, *args, **kwargs):
			if request.user.is_authenticated:
				return redirect(redirect_url)
			return view_function(request, *args, **kwargs)
		
		return wrapped_view
	
	return decorator


from django import VERSION as DJANGO_VERSION

if DJANGO_VERSION >= (2, 0):
	from django.urls import include, re_path as url
else:
	from django.conf.urls import include, url

from . import views

app_name = "ohm2_accounts_light"

urlpatterns = [
	url(r'^api/v1/', include('ohm2_accounts_light.api.v1.urls', namespace = "api_v1")),
]




# Generated by Django 2.0.1 on 2018-11-19 21:19

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ohm2_accounts_light', '0002_auto_20181119_2052'),
    ]

    operations = [
        migrations.AlterField(
            model_name='passwordreset',
            name='code',
            field=models.CharField(max_length=255, unique=True),
        ),
    ]
